Crate arcis_interpreter_proc_macros

Crate arcis_interpreter_proc_macros 

Macros

assert_current_module
Allows to use crate:: in an #encrypted module. Use it like this: assert_current_module!(crate::path::to::encrypted::module);
encrypted_mod
Use another file as a module in an #[encrypted] module.

Attribute Macros

encrypted
Tells our arcis compiler to create encrypted instructions that mimic the rust module you wrote. Use #[instruction] to mark the functions that will be the entry points.
encrypted_library
Validates an arcis library, trying to find errors. Allows to build a library that can be used in #[encrypted] instructions.
instruction
An #[instruction]. Should be inside an #[encrypted] module.